import React, { Component } from "react";

import PropTypes from "prop-types";

import {
  Platform,
  View,
  Text,
  Animated,
  TouchableNativeFeedback,
  TouchableOpacity
} from "react-native";

class SnackBar extends Component {
  constructor(props) {
    super(props);
    this.state = {
      position: new Animated.Value(-48)
    };
  }

  show = () => {
    Animated.timing(this.state.position, {
      delay: 500,
      toValue: 0,
      duration: 200
    }).start();
  };

  hide = () => {
    Animated.spring(this.state.position, {
      delay: 500,
      toValue: -48
    }).start();
  };

  componentDidMount() {
    if (this.props.visible) {
      this.show();
    }
  }

  componentWillReceiveProps(nextState) {
    if (typeof nextState.visible === "boolean" && nextState.visible === true) {
      if (
        this.props.visible === false ||
        typeof this.props.visible === "undefined"
      ) {
        this.show();
      }
    } else if (
      typeof nextState.visible === "boolean" &&
      nextState.visible === false
    ) {
      if (this.props.visible === true) {
        this.hide();
      }
    }
  }

  renderContent = () => {
    return (
      <View
        style={{
          paddingVertical: 8,
          paddingHorizontal: 16,
          height: 48,
          backgroundColor: this.props.backgroundColor || "#212121",
          flexDirection: "row",
          justifyContent: "center",
          alignItems: "center"
        }}
      >
        <Text style={{ flex: 2, color: this.props.textColor || "#ffffff" }}>
          {this.props.text}
        </Text>

        <TouchableOpacity
          style={{ flex: 1 }}
          onPress={() => this.props.onAction && this.props.onAction()}
        >
          <Text style={{ color: this.props.actionTextColor || "#FF9800" }}>
            {this.props.actionText || ""}
          </Text>
        </TouchableOpacity>
      </View>
    );
  };

  renderContainer = () => {
    if (Platform.OS === "ios") {
      return (
        <TouchableOpacity
          onPress={() => this.props.onPress && this.props.onPress()}
        >
          {this.renderContent()}
        </TouchableOpacity>
      );
    } else {
      return (
        <TouchableNativeFeedback
          onPress={() => this.props.onPress && this.props.onPress()}
        >
          {this.renderContent()}
        </TouchableNativeFeedback>
      );
    }
  };

  render() {
    return (
      <Animated.View
        style={{
          position: "absolute",
          left: 0,
          right: 0,
          bottom: this.state.position,
          elevation: 5,
          height: 48
        }}
      >
        {this.renderContainer()}
      </Animated.View>
    );
  }
}

SnackBar.propTypes = {
  text: PropTypes.string.isRequired,
  visible: PropTypes.bool.isRequired,
  onPress: PropTypes.func,
  backgroundColor: PropTypes.string,
  textColor: PropTypes.string,
  onAction: PropTypes.func,
  actionText: PropTypes.string,
  actionTextColor: PropTypes.string
};

export default SnackBar;
